/*
 * Embedded Linux library
 * Copyright (C) 2011-2014  Intel Corporation
 *
 * SPDX-License-Identifier: LGPL-2.1-or-later
 */

#include <ell/util.h>

#define LIB_EXPORT __attribute__ ((visibility("default")))
